adoroszlai commented on PR #11620: URL: https://github.com/apache/ozone/pull/11620#issuecomment-6298293946
Before: ``` [INFO] Tests run: 14, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 37.93 s -- in org.apache.hadoop.ozone.om.TestOzoneManagerHAFollowerReadWithAllRunning [INFO] Tests run: 8, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 162.2 s -- in org.apache.hadoop.ozone.om.TestOzoneManagerHAFollowerReadWithStoppedNodes ``` After: ``` [INFO] Tests run: 14, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 49.60 s -- in org.apache.hadoop.ozone.om.TestOzoneManagerHAFollowerReadWithAllRunning [INFO] Tests run: 8, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 170.4 s -- in org.apache.hadoop.ozone.om.TestOzoneManagerHAFollowerReadWithStoppedNodes ``` Thanks @andyhuangdev for updating the patch, this looks more reasonable. -- This is an automated message from the Apache Git Service. To respond to the message, please log on to GitHub and use the URL above to go to the specific comment. To unsubscribe, e-mail: [email protected] For queries about this service, please contact Infrastructure at: [email protected] --------------------------------------------------------------------- To unsubscribe, e-mail: [email protected] For additional commands, e-mail: [email protected]
